pub struct Client {
pub openrouter_client: Client,
}Expand description
Client that manages connections to all upstream providers.
Handles provider selection, BYOK key injection, and fallback between providers.
Fields
openrouter_client: ClientOpenRouter provider client.
Implementations
Sourceimpl Client
impl Client
Sourcepub async fn create_streaming(
&self,
ctx: Context<impl ContextExt + Send + Sync + 'static>,
id: String,
first_chunk_timeout: Duration,
other_chunk_timeout: Duration,
ensemble_llm: Arc<EnsembleLlm>,
request: Params,
) -> Result<Option<impl Stream<Item = Result<ChatCompletionChunk, Error>> + Send + Unpin + 'static>, Error>
pub async fn create_streaming( &self, ctx: Context<impl ContextExt + Send + Sync + 'static>, id: String, first_chunk_timeout: Duration, other_chunk_timeout: Duration, ensemble_llm: Arc<EnsembleLlm>, request: Params, ) -> Result<Option<impl Stream<Item = Result<ChatCompletionChunk, Error>> + Send + Unpin + 'static>, Error>
Creates a streaming completion, trying each upstream provider in order.
First attempts with BYOK if available, then falls back to the default key.
Returns Ok(None) if no upstreams were available.