Function execution, profile management, and computations. Function operations.
Functions are composable scoring pipelines that combine vector completions and other functions to produce scores.
Modules
- executions
- Function execution client and types. Function execution orchestration.
- function_
fetcher - Fetcher for Function definitions from GitHub. Fetcher for Function definitions from GitHub.
- profile_
fetcher - Fetcher for Profile definitions from GitHub. Fetcher for Profile definitions from GitHub.
- profiles
- Profile operations. Profile operations.
- retrieval_
client - Client for listing functions and getting usage statistics. Client for listing Functions and getting usage statistics.
Structs
- Client
- Client for function operations.
- Function
Flat Task Profile - A flattened function task ready for execution.
- MapFunction
Flat Task Profile - Multiple function tasks from a mapped expression.
- MapVector
Completion Flat Task Profile - Multiple vector completion tasks from a mapped expression.
- Vector
Completion Flat Task Profile - A flattened vector completion task ready for execution.
Enums
- Flat
Task Profile - A flattened task ready for execution.
- Function
Param - Parameter for specifying a function source.
- Function
Type - The type of a Function’s output.
- Profile
Param - Parameter for specifying a profile source.
Functions
- get_
flat_ task_ profile - Recursively builds a flattened task from a Function and Profile.