pub async fn get_flat_task_profile<CTXEXT>(
ctx: Context<CTXEXT>,
path: Vec<u64>,
function: FunctionParam,
profile: ProfileParam,
input: Input,
function_fetcher: Arc<impl Fetcher<CTXEXT> + Send + Sync + 'static>,
profile_fetcher: Arc<impl Fetcher<CTXEXT> + Send + Sync + 'static>,
ensemble_fetcher: Arc<CachingFetcher<CTXEXT, impl Fetcher<CTXEXT> + Send + Sync + 'static>>,
) -> Result<FunctionFlatTaskProfile, Error>Expand description
Recursively builds a flattened task from a Function and Profile.
Fetches any remote Functions/Profiles/Ensembles, compiles task expressions with the input, and validates that the Profile structure matches the Function. The result is a flat tree of tasks ready for parallel execution.