pub struct MapVectorCompletionFlatTaskProfile {
pub path: Vec<u64>,
pub vector_completions: Vec<VectorCompletionFlatTaskProfile>,
}Expand description
Multiple vector completion tasks from a mapped expression.
Created when a vector completion task has a map index. Each element in the
mapped array produces one vector completion instance.
Fields
path: Vec<u64>Path to this task in the Function tree (indices into tasks arrays).
vector_completions: Vec<VectorCompletionFlatTaskProfile>The individual flattened vector completion tasks.
Implementations