pub enum Error {
InvalidProfile(String),
FetchRetry(ResponseError),
RetryNotFound,
FetchCacheVote(ResponseError),
FetchEnsemble(ResponseError),
EnsembleNotFound,
InvalidEnsemble(String),
ExpectedTwoOrMoreRequestVectorResponses(usize),
}Expand description
Errors that can occur during vector completion creation.
Variants
InvalidProfile(String)
The profile weights are invalid.
FetchRetry(ResponseError)
Failed to fetch votes from a previous completion for retry.
RetryNotFound
The completion specified for retry was not found.
FetchCacheVote(ResponseError)
Failed to fetch a vote from the global cache.
FetchEnsemble(ResponseError)
Failed to fetch the Ensemble definition.
EnsembleNotFound
The requested Ensemble was not found.
InvalidEnsemble(String)
The provided Ensemble definition is invalid.
ExpectedTwoOrMoreRequestVectorResponses(usize)
Vector completions require at least two response options.