pub struct ResponseKey {
pub _think: Option<String>,
/* private fields */
}Expand description
Parsed response key from LLM structured output.
Fields
_think: Option<String>Optional synthetic reasoning from the LLM.
Implementations
Sourceimpl ResponseKey
impl ResponseKey
Sourcepub fn response_format(
vector_response_keys: Vec<String>,
think: bool,
) -> ResponseFormat
pub fn response_format( vector_response_keys: Vec<String>, think: bool, ) -> ResponseFormat
Creates a response format for JSON schema output mode.
Constrains the LLM to output a JSON object with the selected response key.
Sourcepub fn tool(vector_response_keys: Vec<String>, think: bool) -> Tool
pub fn tool(vector_response_keys: Vec<String>, think: bool) -> Tool
Creates a tool definition for tool call output mode.
The LLM calls this tool with the selected response key as an argument.
Sourcepub fn tool_choice() -> ToolChoice
pub fn tool_choice() -> ToolChoice
Creates a tool choice that forces the LLM to call the response_key tool.